aind\_metadata\_mapper.open\_ephys package
==========================================

Submodules
----------

aind\_metadata\_mapper.open\_ephys.camstim\_ephys\_session module
-----------------------------------------------------------------

.. automodule:: aind_metadata_mapper.open_ephys.camstim_ephys_session
   :members:
   :undoc-members:
   :show-inheritance:

aind\_metadata\_mapper.open\_ephys.rig module
---------------------------------------------

.. automodule:: aind_metadata_mapper.open_ephys.rig
   :members:
   :undoc-members:
   :show-inheritance:

aind\_metadata\_mapper.open\_ephys.session module
-------------------------------------------------

.. automodule:: aind_metadata_mapper.open_ephys.session
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: aind_metadata_mapper.open_ephys
   :members:
   :undoc-members:
   :show-inheritance:
